init

Function init 

pub fn init(threads: usize) -> Result<()>
Initialize the global thread pool with the default configuration.

This is normally called automatically by rayon, but explicit initialization allows setting the number of threads.

Errors

Returns OcasError::BackendError if the global pool was already initialized with a different configuration.